CommandExtCheck

Trait CommandExtCheck 

pub trait CommandExtCheck {
    type Error;

    // Required method
    fn check(&mut self) -> Result<Output, Self::Error>;
}
Extension trait for std::process::Command to check the output of a command

Required Associated Types

type Error

The error type for the result of checking for an error status

Required Methods

fn check(&mut self) -> Result<Output, Self::Error>

Check the result of a command, returning an error containing the output and error stream content if the status is not success

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl CommandExtCheck for Command

Source

fn check(&mut self) -> Result<Output, Self::Error>

Check the result of a command, returning an error containing the status, output and error stream content if the status is not success

Source

type Error = CommandExtError

Implementors

Source

impl<'a> CommandExtCheck for CommandLog<'a>

Available on crate feature check only.
Source

impl<'a> CommandExtCheck for CommandPrint<'a>

Available on crate feature check only.
Source

impl<'a> CommandExtCheck for CommandTrace<'a>

Available on crate feature check only.